@@ -27,40 +27,17 @@ pub struct Song {
     pub artist: String,
 }
 
-impl Song {
-    pub fn new(id: usize, name: String, album: String, artist: String) -> Self {
-        Self {
-            id,
-            name,
-            album,
-            artist,
-        }
-    }
-}
-
 #[derive(Clone)]
 pub struct Album {
     pub name: String,
     pub artist: String,
 }
 
-impl Album {
-    pub fn new(name: String, artist: String) -> Self {
-        Self { name, artist }
-    }
-}
-
 #[derive(Clone)]
 pub struct Artist {
     pub name: String,
 }
 
-impl Artist {
-    pub fn new(name: String) -> Self {
-        Self { name }
-    }
-}
-
 pub enum Mode {
     Search,
     Select,
@@ -87,6 +64,7 @@ impl Search {
         };
         //TODO: this is dumb
         s.update_engine();
+        s.update_search();
         s
     }
     pub fn update_engine(&mut self) {
@@ -96,20 +74,23 @@ impl Search {
         self.cache = Vec::new();
 
         for (id, song) in songs {
-            self.cache.push(Item::Song(Song::new(
+            self.cache.push(Item::Song(Song {
+                name: song.name,
+                album: song.album,
+                artist: song.artist,
                 id,
-                song.name,
-                song.album,
-                song.artist,
-            )));
+            }));
         }
 
         for (album, artist) in albums {
-            self.cache.push(Item::Album(Album::new(album, artist)));
+            self.cache.push(Item::Album(Album {
+                name: album,
+                artist,
+            }));
         }
 
         for artist in artists {
-            self.cache.push(Item::Artist(Artist::new(artist)));
+            self.cache.push(Item::Artist(Artist { name: artist }));
         }
     }
     pub fn update_search(&mut self) {
@@ -123,6 +104,10 @@ impl Search {
                 Item::Artist(artist) => strsim::jaro_winkler(query, &artist.name.to_lowercase()),
             };
 
+            if query.is_empty() && results.len() < 40 {
+                results.push((item, acc));
+            }
+
             if acc > 0.75 {
                 results.push((item, acc));
             }
@@ -143,15 +128,6 @@ impl Search {
             }
         }
     }
-    pub fn on_tab(&mut self) {
-        match self.mode {
-            Mode::Search => {
-                self.results.select(None);
-                self.query.clear();
-            }
-            Mode::Select => (),
-        }
-    }
     pub fn up(&mut self) {
         self.results.up();
     }
@@ -358,61 +334,37 @@ impl Search {
         f.render_widget(artist_table, area);
     }
     fn draw_results<B: Backend>(&self, f: &mut Frame<B>, area: Rect) {
-        let get_cell = |item: &Item, modifier: Modifier| -> Row {
+        let get_cell = |item: &Item, selected: bool| -> Row {
+            let selected_cell = if selected {
+                Cell::from(">")
+            } else {
+                Cell::default()
+            };
             match item {
                 Item::Song(song) => {
                     let song = &sqlite::get_songs_from_id(&[song.id])[0];
                     Row::new(vec![
-                        Cell::from(song.name.clone()).style(
-                            Style::default()
-                                .fg(self.colors.title)
-                                .add_modifier(modifier),
-                        ),
-                        Cell::from(song.album.clone()).style(
-                            Style::default()
-                                .fg(self.colors.album)
-                                .add_modifier(modifier),
-                        ),
-                        Cell::from(song.artist.clone()).style(
-                            Style::default()
-                                .fg(self.colors.artist)
-                                .add_modifier(modifier),
-                        ),
+                        selected_cell,
+                        Cell::from(song.name.clone()).style(Style::default().fg(self.colors.title)),
+                        Cell::from(song.album.clone())
+                            .style(Style::default().fg(self.colors.album)),
+                        Cell::from(song.artist.clone())
+                            .style(Style::default().fg(self.colors.artist)),
                     ])
                 }
                 Item::Album(album) => Row::new(vec![
-                    Cell::from(format!("{} - Album", album.name)).style(
-                        Style::default()
-                            .fg(self.colors.title)
-                            .add_modifier(modifier),
-                    ),
-                    Cell::from("").style(
-                        Style::default()
-                            .fg(self.colors.album)
-                            .add_modifier(modifier),
-                    ),
-                    Cell::from(album.artist.clone()).style(
-                        Style::default()
-                            .fg(self.colors.artist)
-                            .add_modifier(modifier),
-                    ),
+                    selected_cell,
+                    Cell::from(format!("{} - Album", album.name))
+                        .style(Style::default().fg(self.colors.title)),
+                    Cell::from("").style(Style::default().fg(self.colors.album)),
+                    Cell::from(album.artist.clone()).style(Style::default().fg(self.colors.artist)),
                 ]),
                 Item::Artist(artist) => Row::new(vec![
-                    Cell::from(format!("{} - Artist", artist.name)).style(
-                        Style::default()
-                            .fg(self.colors.title)
-                            .add_modifier(modifier),
-                    ),
-                    Cell::from("").style(
-                        Style::default()
-                            .fg(self.colors.album)
-                            .add_modifier(modifier),
-                    ),
-                    Cell::from("").style(
-                        Style::default()
-                            .fg(self.colors.artist)
-                            .add_modifier(modifier),
-                    ),
+                    selected_cell,
+                    Cell::from(format!("{} - Artist", artist.name))
+                        .style(Style::default().fg(self.colors.title)),
+                    Cell::from("").style(Style::default().fg(self.colors.album)),
+                    Cell::from("").style(Style::default().fg(self.colors.artist)),
                 ]),
             }
         };
@@ -426,12 +378,12 @@ impl Search {
             .map(|(i, item)| {
                 if let Some(s) = selected {
                     if s == &i {
-                        return get_cell(item, Modifier::ITALIC);
+                        return get_cell(item, true);
                     }
                 } else if i == 0 {
-                    return get_cell(item, Modifier::ITALIC);
+                    return get_cell(item, false);
                 }
-                get_cell(item, Modifier::empty())
+                get_cell(item, false)
             })
             .collect();
 
@@ -439,6 +391,7 @@ impl Search {
         let t = Table::new(rows)
             .header(
                 Row::new(vec![
+                    Cell::default(),
                     Cell::from("Name").style(italic),
                     Cell::from("Album").style(italic),
                     Cell::from("Artist").style(italic),
@@ -451,11 +404,11 @@ impl Search {
                     .border_type(BorderType::Rounded),
             )
             .widths(&[
+                Constraint::Length(1),
                 Constraint::Percentage(40),
                 Constraint::Percentage(40),
                 Constraint::Percentage(20),
-            ])
-            .highlight_symbol("> ");
+            ]);
 
         let mut state = TableState::new(self.results.index);
         f.render_stateful_widget(t, area, &mut state);
